pub enum InputCodecRegistryError {
DuplicateName(String),
DuplicateExtension(String),
}Expand description
Error returned when an input-codec registration conflicts with an existing codec.
Variants
DuplicateName(String)
Two codecs for the same result type use the same normalized name.
DuplicateExtension(String)
Two codecs for the same result type use the same normalized extension.