Mapped

Struct Mapped 

pub struct Mapped<A, F> {
    pub inner: A,
    pub map: F,
}
Symbol-renaming view of an automaton.

Mapped is useful when an automaton should be queried under a different external signature. The mapping is applied to every input symbol before the wrapped automaton is queried. States are unchanged.

Fields

inner: A

Wrapped automaton.

map: F

Function from external symbol IDs to the wrapped automaton’s symbol IDs.

Implementations

Source

impl<A, F> Mapped<A, F>

pub fn new(inner: A, map: F) -> Self

Create a mapped view.