pub enum CorpusError {
Io(Error),
BadHeader,
BadVersion,
MalformedInstance {
line: usize,
expected: usize,
found: usize,
},
ObjectParse {
line: usize,
interpretation: String,
message: String,
},
TreeParse {
line: usize,
message: String,
},
}Expand description
Errors returned while reading a corpus.
Variants
Io(Error)
An I/O error occurred.
BadHeader
The header line did not match <prefix>IRTG (un)annotated corpus file, v1.0.
BadVersion
The header declared an unsupported corpus version.
MalformedInstance
An instance did not have the expected number of lines.
Fields
ObjectParse
An interpretation line could not be parsed by its algebra.
Fields
TreeParse
A derivation-tree line could not be parsed.