HomomorphismError

Enum HomomorphismError 

pub enum HomomorphismError {
    ArityMismatch {
        symbol: Symbol,
        first: usize,
        second: usize,
    },
    ConflictingSourceTerm {
        symbol: Symbol,
    },
    MissingVariable {
        symbol: Symbol,
        variable: usize,
    },
    DuplicateVariable {
        symbol: Symbol,
        variable: usize,
    },
    OutOfRangeVariable {
        symbol: Symbol,
        variable: usize,
        arity: usize,
    },
    UnmappedSymbol {
        symbol: Symbol,
    },
    ApplyVariableOutOfRange {
        variable: usize,
        arity: usize,
    },
}
Error returned when constructing or applying a homomorphism.

Variants



ArityMismatch

The same source symbol was registered twice with different source arity.

Fields

symbol: Symbol

Source symbol whose arity conflicts.

first: usize

Previously registered arity.

second: usize

Newly requested arity.



ConflictingSourceTerm

The same source symbol was registered twice with different image terms.

Fields

symbol: Symbol

Source symbol whose image term conflicts.



MissingVariable

A required variable does not occur in the image term.

Fields

symbol: Symbol

Source symbol being registered.

variable: usize

Missing source-child variable.



DuplicateVariable

A variable occurs more than once in the image term.

Fields

symbol: Symbol

Source symbol being registered.

variable: usize

Duplicated source-child variable.



OutOfRangeVariable

The image term mentions a variable outside the source arity.

Fields

symbol: Symbol

Source symbol being registered.

variable: usize

Variable index found in the image.

arity: usize

Source arity of the symbol.



UnmappedSymbol

A source tree contains a symbol for which no image term was registered.

Fields

symbol: Symbol

Unmapped source symbol.



ApplyVariableOutOfRange

Applying a homomorphism found a variable that has no corresponding child.

Fields

variable: usize

Variable index in the image term.

arity: usize

Number of mapped source children available.