pub struct Symbol(pub u32);Expand description
Identifier for a node label or grammar symbol.
The library deliberately does not intern or interpret symbols. Your
application owns the signature and maps labels such as "a" or "concat"
to Symbol values.
Tuple Fields
0: u32Trait Implementations
impl Copy for Symbol
impl Eq for Symbol
Sourceimpl FromIterator<Symbol> for SymbolSet
impl FromIterator<Symbol> for SymbolSet
Sourceimpl Ord for Symbol
impl Ord for Symbol
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Symbol
impl PartialOrd for Symbol
impl StructuralPartialEq for Symbol