pub struct NonDetRun<S> {
pub states: Vec<StateSet<S>>,
pub root_states: StateSet<S>,
}Expand description
Side table produced by run_nondet.
Each node can have zero or more possible states. An empty set means the subtree rooted at that node is rejected.
Fields
states: Vec<StateSet<S>>State set assigned to each node, indexed by Tree::index.
root_states: StateSet<S>State set assigned to the root.