pub struct StateSet<S>(/* private fields */);Expand description
Small sorted set of states used by nondeterministic runs.
The set keeps states deduplicated. It stores a few states inline, which is efficient for the common case where each node has only a small number of possible states.
Implementations