pub enum HomomorphismError {
ArityMismatch {
symbol: Symbol,
first: usize,
second: usize,
},
ConflictingSourceTerm {
symbol: Symbol,
},
MissingVariable {
symbol: Symbol,
variable: usize,
},
DuplicateVariable {
symbol: Symbol,
variable: usize,
},
OutOfRangeVariable {
symbol: Symbol,
variable: usize,
arity: usize,
},
UnmappedSymbol {
symbol: Symbol,
},
ApplyVariableOutOfRange {
variable: usize,
arity: usize,
},
}Expand description
Error returned when constructing or applying a homomorphism.
Variants
ArityMismatch
The same source symbol was registered twice with different source arity.
Fields
ConflictingSourceTerm
The same source symbol was registered twice with different image terms.
MissingVariable
A required variable does not occur in the image term.
DuplicateVariable
A variable occurs more than once in the image term.
Fields
OutOfRangeVariable
The image term mentions a variable outside the source arity.
Fields
UnmappedSymbol
A source tree contains a symbol for which no image term was registered.
ApplyVariableOutOfRange
Applying a homomorphism found a variable that has no corresponding child.