StateSet

Struct StateSet 

pub struct StateSet<S>(/* private fields */);
Small sorted set of states used by nondeterministic runs.

The set keeps states deduplicated. It stores a few states inline, which is efficient for the common case where each node has only a small number of possible states.

Implementations

Source

impl<S: Clone + Ord> StateSet<S>

pub fn new() -> Self

Create an empty state set.

pub fn insert(&mut self, s: S)

Insert a state, preserving sorted and deduplicated order.

pub fn iter(&self) -> impl Iterator<Item = &S>

Iterate over states in sorted order.

pub fn as_slice(&self) -> &[S]

Return the states as a slice.

pub fn is_empty(&self) -> bool

Return whether this set contains no states.

pub fn len(&self) -> usize

Return the number of states in the set.